@@ -177,7 +177,7 @@ define('pgadmin.node.synonym', [
         },{
           id: 'is_public_synonym', label: gettext('Public synonym?'),
           disabled: true, type: 'switch', mode: ['properties'], cell: 'switch',
-          options: { onText: 'Yes', offText: 'No', onColor: 'success',
+          options: { onText: gettext('Yes'), offText: gettext('No'), onColor: 'success',
                     offColor: 'primary', size: 'mini'}
         }
         ],
