@@ -6,10 +6,7 @@
 
 {% endif %}
 {% if data.name and data.schema and data.definition %}
-CREATE OR REPLACE VIEW {{ conn|qtIdent(data.schema, data.name) }}{% if (data.security_barrier) %}{{'\r'}}
-WITH (
-{% if data.security_barrier %}    security_barrier={{ data.security_barrier|lower }}{% endif %}{{'\r'}}
-){% endif %} AS
+CREATE OR REPLACE VIEW {{ conn|qtIdent(data.schema, data.name) }} AS
 {{ data.definition.rstrip(';') }};
 {% if data.owner %}
 
@@ -17,7 +14,6 @@ ALTER TABLE {{ conn|qtIdent(data.schema, data.name) }}
     OWNER TO {{ conn|qtIdent(data.owner) }};
 {% endif %}
 {% if data.comment %}
-
 COMMENT ON VIEW {{ conn|qtIdent(data.schema, data.name) }}
     IS {{ data.comment|qtLiteral }};
 {% endif %}
