@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -460,7 +460,7 @@ rolmembership:{
 
                 if not self.conn.connected():
                     return precondition_required(
-                        _("Connection to the server has been lost!")
+                        _("Connection to the server has been lost.")
                     )
 
                 ver = self.manager.version
