@@ -64,7 +64,7 @@ Snap.plugin(function (Snap, Element, Paper, glob) {
           );
 
       if (curr_line) {
-        lines = lines.slice(0, lines.length - 2);
+        lines = lines.slice(0, lines.length - 1);
       }
       lines = lines.concat(tmpArr);
       curr_line = lines[lines.length - 1];
@@ -95,76 +95,76 @@ var pgExplain = pgAdmin.Explain = {
  */
 var imageMapper = {
     "Aggregate" : {
-        "image":"ex_aggregate.png", "image_text":"Aggregate"
+        "image":"ex_aggregate.svg", "image_text":"Aggregate"
     },
     'Append' : {
-        "image":"ex_append.png","image_text":"Append"
+        "image":"ex_append.svg","image_text":"Append"
     },
     "Bitmap Index Scan" : function(data) {
         return {
-            "image":"ex_bmp_index.png", "image_text":data['Index Name']
+            "image":"ex_bmp_index.svg", "image_text":data['Index Name']
         };
     },
     "Bitmap Heap Scan" : function(data) {
-  return {"image":"ex_bmp_heap.png","image_text":data['Relation Name']};
+  return {"image":"ex_bmp_heap.svg","image_text":data['Relation Name']};
 },
-"BitmapAnd" : {"image":"ex_bmp_and.png","image_text":"Bitmap AND"},
-"BitmapOr" : {"image":"ex_bmp_or.png","image_text":"Bitmap OR"},
-"CTE Scan" : {"image":"ex_cte_scan.png","image_text":"CTE Scan"},
-"Function Scan" : {"image":"ex_result.png","image_text":"Function Scan"},
-"Foreign Scan" : {"image":"ex_foreign_scan.png","image_text":"Foreign Scan"},
-"Gather" : {"image":"ex_gather_motion.png","image_text":"Gather"},
-"Group" : {"image":"ex_group.png","image_text":"Group"},
-"GroupAggregate": {"image":"ex_aggregate.png","image_text":"Group Aggregate"},
-"Hash" : {"image":"ex_hash.png","image_text":"Hash"},
+"BitmapAnd" : {"image":"ex_bmp_and.svg","image_text":"Bitmap AND"},
+"BitmapOr" : {"image":"ex_bmp_or.svg","image_text":"Bitmap OR"},
+"CTE Scan" : {"image":"ex_cte_scan.svg","image_text":"CTE Scan"},
+"Function Scan" : {"image":"ex_result.svg","image_text":"Function Scan"},
+"Foreign Scan" : {"image":"ex_foreign_scan.svg","image_text":"Foreign Scan"},
+"Gather" : {"image":"ex_gather_motion.svg","image_text":"Gather"},
+"Group" : {"image":"ex_group.svg","image_text":"Group"},
+"GroupAggregate": {"image":"ex_aggregate.svg","image_text":"Group Aggregate"},
+"Hash" : {"image":"ex_hash.svg","image_text":"Hash"},
 "Hash Join": function(data) {
-  if (!data['Join Type']) return {"image":"ex_join.png","image_text":"Join"};
+  if (!data['Join Type']) return {"image":"ex_join.svg","image_text":"Join"};
   switch(data['Join Type']) {
-    case 'Anti': return {"image":"ex_hash_anti_join.png","image_text":"Hash Anti Join"};
-    case 'Semi': return {"image":"ex_hash_semi_join.png","image_text":"Hash Semi Join"};
-    default: return {"image":"ex_hash.png","image_text":String("Hash " + data['Join Type'] + " Join" )};
+    case 'Anti': return {"image":"ex_hash_anti_join.svg","image_text":"Hash Anti Join"};
+    case 'Semi': return {"image":"ex_hash_semi_join.svg","image_text":"Hash Semi Join"};
+    default: return {"image":"ex_hash.svg","image_text":String("Hash " + data['Join Type'] + " Join" )};
   }
 },
-"HashAggregate" : {"image":"ex_aggregate.png","image_text":"Hash Aggregate"},
+"HashAggregate" : {"image":"ex_aggregate.svg","image_text":"Hash Aggregate"},
 "Index Only Scan" : function(data) {
-  return {"image":"ex_index_only_scan.png","image_text":data['Index Name']};
+  return {"image":"ex_index_only_scan.svg","image_text":data['Index Name']};
 },
 "Index Scan" : function(data) {
-  return {"image":"ex_index_scan.png","image_text":data['Index Name']};
+  return {"image":"ex_index_scan.svg","image_text":data['Index Name']};
 },
-"Index Scan Backword" : {"image":"ex_index_scan.png","image_text":"Index Backward Scan"},
-"Limit" : {"image":"ex_limit.png","image_text":"Limit"},
-"LockRows" : {"image":"ex_lock_rows.png","image_text":"Lock Rows"},
-"Materialize" : {"image":"ex_materialize.png","image_text":"Materialize"},
-"Merge Append": {"image":"ex_merge_append.png","image_text":"Merge Append"},
+"Index Scan Backword" : {"image":"ex_index_scan.svg","image_text":"Index Backward Scan"},
+"Limit" : {"image":"ex_limit.svg","image_text":"Limit"},
+"LockRows" : {"image":"ex_lock_rows.svg","image_text":"Lock Rows"},
+"Materialize" : {"image":"ex_materialize.svg","image_text":"Materialize"},
+"Merge Append": {"image":"ex_merge_append.svg","image_text":"Merge Append"},
 "Merge Join": function(data) {
   switch(data['Join Type']) {
-    case 'Anti': return {"image":"ex_merge_anti_join.png","image_text":"Merge Anti Join"};
-    case 'Semi': return {"image":"ex_merge_semi_join.png","image_text":"Merge Semi Join"};
-    default: return {"image":"ex_merge.png","image_text":String("Merge " + data['Join Type'] + " Join" )};
+    case 'Anti': return {"image":"ex_merge_anti_join.svg","image_text":"Merge Anti Join"};
+    case 'Semi': return {"image":"ex_merge_semi_join.svg","image_text":"Merge Semi Join"};
+    default: return {"image":"ex_merge.svg","image_text":String("Merge " + data['Join Type'] + " Join" )};
   }
 },
 "ModifyTable" : function(data) {
   switch (data['Operation']) {
-    case "Insert": return { "image":"ex_insert.png",
+    case "Insert": return { "image":"ex_insert.svg",
                             "image_text":"Insert"
                            };
-    case "Update": return {"image":"ex_update.png","image_text":"Update"};
-    case "Delete": return {"image":"ex_delete.png","image_text":"Delete"};
+    case "Update": return {"image":"ex_update.svg","image_text":"Update"};
+    case "Delete": return {"image":"ex_delete.svg","image_text":"Delete"};
   }
 },
 'Nested Loop' : function(data) {
   switch(data['Join Type']) {
-    case 'Anti': return {"image":"ex_nested_loop_anti_join.png","image_text":"Nested Loop Anti Join"};
-    case 'Semi': return {"image":"ex_nested_loop_semi_join.png","image_text":"Nested Loop Semi Join"};
-    default: return {"image":"ex_nested.png","image_text":"Nested Loop " + data['Join Type'] + " Join"};
+    case 'Anti': return {"image":"ex_nested_loop_anti_join.svg","image_text":"Nested Loop Anti Join"};
+    case 'Semi': return {"image":"ex_nested_loop_semi_join.svg","image_text":"Nested Loop Semi Join"};
+    default: return {"image":"ex_nested.svg","image_text":"Nested Loop " + data['Join Type'] + " Join"};
   }
 },
-"Recursive Union" : {"image":"ex_recursive_union.png","image_text":"Recursive Union"},
-"Result" : {"image":"ex_result.png","image_text":"Result"},
-"Sample Scan" : {"image":"ex_scan.png","image_text":"Sample Scan"},
-"Scan" : {"image":"ex_scan.png","image_text":"Scan"},
-"Seek" : {"image":"ex_seek.png","image_text":"Seek"},
+"Recursive Union" : {"image":"ex_recursive_union.svg","image_text":"Recursive Union"},
+"Result" : {"image":"ex_result.svg","image_text":"Result"},
+"Sample Scan" : {"image":"ex_scan.svg","image_text":"Sample Scan"},
+"Scan" : {"image":"ex_scan.svg","image_text":"Scan"},
+"Seek" : {"image":"ex_seek.svg","image_text":"Seek"},
 "SetOp" : function(data) {
   var strategy = data['Strategy'],
       command = data['Command'];
@@ -172,29 +172,29 @@ var imageMapper = {
   if(strategy == "Hashed") {
     if(S.startsWith(command, "Intersect")) {
       if(command == "Intersect All")
-        return {"image":"ex_hash_setop_intersect_all.png","image_text":"Hashed Intersect All"};
-      return {"image":"ex_hash_setop_intersect.png","image_text":"Hashed Intersect"};
+        return {"image":"ex_hash_setop_intersect_all.svg","image_text":"Hashed Intersect All"};
+      return {"image":"ex_hash_setop_intersect.svg","image_text":"Hashed Intersect"};
     }
     else if (S.startsWith(command, "Except")) {
       if(command == "Except All")
-        return {"image":"ex_hash_setop_except_all.png","image_text":"Hashed Except All"};
-      return {"image":"ex_hash_setop_except.png","image_text":"Hash Except"};
+        return {"image":"ex_hash_setop_except_all.svg","image_text":"Hashed Except All"};
+      return {"image":"ex_hash_setop_except.svg","image_text":"Hash Except"};
     }
-    return {"image":"ex_hash_setop_unknown.png","image_text":"Hashed SetOp Unknown"};
+    return {"image":"ex_hash_setop_unknown.svg","image_text":"Hashed SetOp Unknown"};
   }
-  return {"image":"ex_setop.png","image_text":"SetOp"};
+  return {"image":"ex_setop.svg","image_text":"SetOp"};
 },
 "Seq Scan": function(data) {
-  return {"image":"ex_scan.png","image_text":data['Relation Name']};
+  return {"image":"ex_scan.svg","image_text":data['Relation Name']};
 },
-"Subquery Scan" : {"image":"ex_subplan.png","image_text":"SubQuery Scan"},
-"Sort" : {"image":"ex_sort.png","image_text":"Sort"},
-"Tid Scan" : {"image":"ex_tid_scan.png","image_text":"Tid Scan"},
-"Unique" : {"image":"ex_unique.png","image_text":"Unique"},
-"Values Scan" : {"image":"ex_values_scan.png","image_text":"Values Scan"},
-"WindowAgg" : {"image":"ex_window_aggregate.png","image_text":"Window Aggregate"},
-"WorkTable Scan" : {"image":"ex_worktable_scan.png","image_text":"WorkTable Scan"},
-"Undefined" : {"image":"ex_unknown.png","image_text":"Undefined"},
+"Subquery Scan" : {"image":"ex_subplan.svg","image_text":"SubQuery Scan"},
+"Sort" : {"image":"ex_sort.svg","image_text":"Sort"},
+"Tid Scan" : {"image":"ex_tid_scan.svg","image_text":"Tid Scan"},
+"Unique" : {"image":"ex_unique.svg","image_text":"Unique"},
+"Values Scan" : {"image":"ex_values_scan.svg","image_text":"Values Scan"},
+"WindowAgg" : {"image":"ex_window_aggregate.svg","image_text":"Window Aggregate"},
+"WorkTable Scan" : {"image":"ex_worktable_scan.svg","image_text":"WorkTable Scan"},
+"Undefined" : {"image":"ex_unknown.svg","image_text":"Undefined"},
 }
 
 // Some predefined constants used to calculate image location and its border
@@ -207,7 +207,7 @@ var offsetX = 200,
 var ARROW_WIDTH = 10,
     ARROW_HEIGHT = 10,
     DEFAULT_ARROW_SIZE = 2;
-var TXT_ALLIGN = 5,
+var TXT_ALIGN = 5,
     TXT_SIZE = "15px";
 var TOTAL_WIDTH = undefined,
     TOTAL_HEIGHT = undefined;
@@ -263,7 +263,7 @@ var PlanModel = Backbone.Model.extend({
         var mappedImage = (_.isFunction(imageMapper[node_type]) &&
                 imageMapper[node_type].apply(undefined, [data])) ||
                 imageMapper[node_type] || {
-                  "image": "ex_unknown.png", "image_text": node_type
+                  "image": "ex_unknown.svg", "image_text": node_type
                 };
 
         data["image"] = mappedImage["image"];
@@ -376,9 +376,10 @@ var PlanModel = Backbone.Model.extend({
         if (isSubPlan) {
           g.rect(
             currentXpos - this.get('width') + pWIDTH + xMargin,
-            currentYpos - yMargin,
+            currentYpos - this.get('height') + pHEIGHT + yMargin - TXT_ALIGN,
             this.get('width') - xMargin,
-            this.get('height'), 5
+            this.get('height') + (currentYpos - yMargin),
+            5
           ).attr({
               stroke: '#444444',
               'strokeWidth': 1.2,
@@ -461,8 +462,8 @@ var PlanModel = Backbone.Model.extend({
                             this.get('Schema')+"."+this.get('image_text'));
         var label = g.g();
         g.multitext(
-          currentXpos + (pWIDTH / 2),
-          currentYpos + pHEIGHT - TXT_ALLIGN,
+          currentXpos + (pWIDTH / 2) + TXT_ALIGN,
+          currentYpos + pHEIGHT - TXT_ALIGN,
           node_label,
           150,
           {"font-size": TXT_SIZE ,"text-anchor":"middle"}
@@ -531,7 +532,7 @@ var MainPlanModel = Backbone.Model.extend({
            data['xpos'] = 0;
            data['ypos'] = 0;
            data['width'] = plan.get('width') + (xMargin * 2);
-           data['height'] = plan.get('height') + (yMargin * 2);
+           data['height'] = plan.get('height') + (yMargin * 4);
 
            delete data['Plan'];
         }
