@@ -2,37 +2,39 @@
   // Set up Backform appropriately for the environment. Start with AMD.
   if (typeof define === 'function' && define.amd) {
     define([
-      'underscore', 'jquery', 'backbone', 'backform', 'backgrid', 'alertify',
-      'moment', 'bignumber', 'bootstrap.datetimepicker'
+      'sources/gettext', 'underscore', 'jquery', 'backbone', 'backform', 'backgrid', 'alertify',
+      'moment', 'bignumber', 'bootstrap.datetimepicker', 'bootstrap.switch'
     ],
-     function(_, $, Backbone, Backform, Backgrid, Alertify, moment, BigNumber) {
+     function(gettext, _, $, Backbone, Backform, Backgrid, Alertify, moment, BigNumber) {
       // Export global even in AMD case in case this script is loaded with
       // others that may still expect a global Backform.
-      return factory(root, _, $, Backbone, Backform, Alertify, moment, BigNumber);
+      return factory(root, gettext, _, $, Backbone, Backform, Backgrid, Alertify, moment, BigNumber);
     });
 
   // Next for Node.js or CommonJS. jQuery may not be needed as a module.
   } else if (typeof exports !== 'undefined') {
-    var _ = require('underscore') || root._,
+    var gettext = require('sources/gettext'),
+      _ = require('underscore') || root._,
       $ = root.jQuery || root.$ || root.Zepto || root.ender,
       Backbone = require('backbone') || root.Backbone,
-      Backform = require('backform') || root.Backform;
-      Alertify = require('alertify') || root.Alertify;
+      Backform = require('backform') || root.Backform,
+      Backgrid = require('backgrid') || root.Backgrid,
+      Alertify = require('alertify') || root.Alertify,
       moment = require('moment') || root.moment;
-    factory(root, _, $, Backbone, Backform, Alertify, moment);
+    factory(root, gettext, _, $, Backbone, Backform, Backgrid, Alertify, moment);
 
   // Finally, as a browser global.
   } else {
-    factory(root, root._, (root.jQuery || root.Zepto || root.ender || root.$), root.Backbone, root.Backform);
+    factory(root, root.gettext, root._, (root.jQuery || root.Zepto || root.ender || root.$), root.Backbone, root.Backform, root.Alertify, root.moment);
   }
-} (this, function(root, _, $, Backbone, Backform, Alertify, moment, BigNumber) {
+} (this, function(root, gettext, _, $, Backbone, Backform, Backgrid, Alertify, moment, BigNumber) {
   /*
      * Add mechanism in backgrid to render different types of cells in
      * same column;
    */
 
   // Add new property cellFunction in Backgrid.Column.
-  _.extend(Backgrid.Column.prototype.defaults, { cellFunction: undefined });
+  _.extend(Backgrid.Column.prototype.defaults, {cellFunction: undefined});
 
   // Add tooltip to cell if cell content is larger than
   // cell width
@@ -117,6 +119,7 @@
         // extract the values from the models
 
         var l = func(left, attr), r = func(right, attr), t;
+        if (_.isUndefined(l) || _.isUndefined(r)) return;
 
         var types = ['number-cell', 'integer-cell'];
         if (_.include(types, type)) {
@@ -213,13 +216,15 @@
     },
     postRender: function(model, column) {
       var editor = this,
-          el = this.el;
-          columns_length = this.columns_length;
+          el = this.el,
+          columns_length = this.columns_length,
+          // To render schema directly from Backgrid cell we use columns schema attribute
+          schema = this.schema.length ? this.schema : this.column.get('schema');
 
       if (column != null && column.get("name") != this.column.get("name"))
         return false;
 
-      if (!_.isArray(this.schema)) throw new TypeError("schema must be an array");
+      if (!_.isArray(schema)) throw new TypeError("schema must be an array");
 
       // Create a Backbone model from our object if it does not exist
       var $dialog = this.createDialog(columns_length);
@@ -229,10 +234,10 @@
       $dialog.find('div.subnode-body').append($form);
 
       // Call Backform to prepare dialog
-      back_el = $dialog.find('form.form-dialog');
+      var back_el = $dialog.find('form.form-dialog');
 
       this.objectView = new Backform.Dialog({
-        el: back_el, model: this.model, schema: this.schema,
+        el: back_el, model: this.model, schema: schema,
         tabPanelClassName: function() {
           return 'sub-node-form col-sm-12';
         }
@@ -279,7 +284,7 @@
     // It's possible to render an option group or use a
     // function to provide option values too.
     optionValues: function() {
-      var res = [];
+      var res = [],
           opts = _.result(this.column.attributes, 'options');
       _.each(opts, function(o) {
         res.push([o.label, o.value]);
@@ -340,7 +345,7 @@
             );
         }
       } else {
-          Alertify.alert("This object is not editable by user",
+          Alertify.alert(gettext("This object is not user editable."),
             function(){
               return true;
           });
@@ -380,7 +385,8 @@
 
   var DeleteCell = Backgrid.Extension.DeleteCell = Backgrid.Cell.extend({
       defaults: _.defaults({
-        defaultDeleteMsg: 'Are you sure you wish to delete this row?'
+        defaultDeleteMsg: gettext('Are you sure you wish to delete this row?'),
+        defaultDeleteTitle: gettext('Delete Row')
       }, Backgrid.Cell.prototype.defaults),
 
       /** @property */
@@ -390,7 +396,7 @@
       },
       deleteRow: function (e) {
         e.preventDefault();
-        that = this;
+        var that = this;
         // We will check if row is deletable or not
         var canDeleteRow = (!_.isUndefined(this.column.get('canDeleteRow')) &&
                             _.isFunction(this.column.get('canDeleteRow')) ) ?
@@ -399,8 +405,10 @@
         if (canDeleteRow) {
           var delete_msg = !_.isUndefined(this.column.get('customDeleteMsg')) ?
                            this.column.get('customDeleteMsg'): that.defaults.defaultDeleteMsg;
+          var delete_title = !_.isUndefined(this.column.get('customDeleteTitle')) ?
+                           this.column.get('customDeleteTitle'): that.defaults.defaultDeleteTitle;
           Alertify.confirm(
-            'Delete Row',
+            delete_title,
             delete_msg,
             function(evt) {
               that.model.collection.remove(that.model);
@@ -410,7 +418,7 @@
             }
           );
         } else {
-          Alertify.alert("This object cannot be deleted",
+          Alertify.alert(gettext("This object cannot be deleted."),
             function(){
               return true;
             }
@@ -442,11 +450,12 @@
   /**
     SwitchCell renders a Bootstrap Switch in backgrid cell
   */
+  $.fn.bootstrapSwitch = jQuery.fn.bootstrapSwitch;
   var SwitchCell = Backgrid.Extension.SwitchCell = Backgrid.BooleanCell.extend({
     defaults: {
       options: _.defaults({
-        onText: 'True',
-        offText: 'False',
+        onText: gettext('True'),
+        offText: gettext('False'),
         onColor: 'success',
         offColor: 'default',
         size: 'mini'
@@ -478,6 +487,7 @@
           column = this.column,
           val = this.formatter.toRaw(this.$input.prop('checked'), model);
 
+      this.enterEditMode();
       // on bootstrap change we also need to change model's value
       model.set(column.get("name"), val);
     },
@@ -640,7 +650,7 @@
             ),
           selectTpl = _.template('<select <%=multiple ? "multiple" : "" %>></select>');
 
-      $select = self.$select = $(selectTpl({
+      var $select = self.$select = $(selectTpl({
         multiple: select2_opts.multiple
       })).appendTo(self.$el);
 
@@ -763,7 +773,7 @@
         "click": "addHeaderIcon"
       },
       addHeaderIcon: function (e) {
-        self = this;
+        var self = this,
         m = new (this.collection.model);
         this.collection.add(m)
         e.preventDefault();
@@ -800,7 +810,7 @@
             arrayValuesCol = this.model.get(this.column.get("name")),
             tbl = $("<table></table>").appendTo(this.$el),
             gridCols = [
-                    {name: 'value', label:'Array Values', type: 'text', cell:'string', headerCell: Backgrid.Extension.CustomHeaderIconCell, cellHeaderClasses: 'width_percent_100'},
+                    {name: 'value', label: gettext('Array Values'), type: 'text', cell:'string', headerCell: Backgrid.Extension.CustomHeaderIconCell, cellHeaderClasses: 'width_percent_100'},
                     ],
             gridBody = $("<div class='pgadmin-control-group backgrid form-group col-xs-12 object subnode'></div>");
 
@@ -870,7 +880,7 @@
           }, 10);
 
 
-        }},10);
+        } },10);
       return;
     }
   });
@@ -1003,7 +1013,7 @@
 
         if (deps && _.isArray(deps)) {
           _.each(deps, function(d) {
-            attrArr = d.split('.');
+            var attrArr = d.split('.'),
             name = attrArr.shift();
             self.listenTo(self.model, "change:" + name, self.dependentChanged);
           });
@@ -1016,8 +1026,8 @@
 
         if (deps && _.isArray(deps)) {
           _.each(deps, function(d) {
-            attrArr = d.split('.');
-            name = attrArr.shift();
+            var attrArr = d.split('.'),
+              name = attrArr.shift();
 
             self.stopListening(self.model, "change:" + name, self.dependentChanged);
           });
@@ -1354,9 +1364,9 @@
     },
     closeIt: function(ev) {
       var formatter = this.formatter,
-          model = this.model;
-          column = this.column;
-          val = this.$el.val();
+          model = this.model,
+          column = this.column,
+          val = this.$el.val(),
           newValue = formatter.toRaw(val, model);
 
       if (this.is_closing)
@@ -1378,6 +1388,58 @@
 
   _.extend(MomentCell.prototype, MomentFormatter.prototype.defaults);
 
+
+  Backgrid.Extension.StringDepCell = Backgrid.StringCell.extend({
+      initialize: function() {
+        Backgrid.StringCell.prototype.initialize.apply(this, arguments);
+        Backgrid.Extension.DependentCell.prototype.initialize.apply(this, arguments);
+      },
+      dependentChanged: function () {
+        this.$el.empty();
+
+        var self = this,
+            model = this.model,
+            column = this.column,
+            editable = this.column.get("editable");
+
+        this.render();
+
+        var is_editable = _.isFunction(editable) ? !!editable.apply(column, [model]) : !!editable;
+        setTimeout(function() {
+          self.$el.removeClass("editor");
+          if (is_editable){ self.$el.addClass("editable"); }
+          else { self.$el.removeClass("editable"); }
+        }, 10);
+
+        this.delegateEvents();
+        return this;
+      },
+      remove: Backgrid.Extension.DependentCell.prototype.remove
+    });
+
+  Backgrid.Extension.Select2DepCell = Backgrid.Extension.Select2Cell.extend({
+    initialize: function() {
+      Backgrid.Extension.Select2Cell.prototype.initialize.apply(this, arguments);
+      Backgrid.Extension.DependentCell.prototype.initialize.apply(this, arguments);
+    },
+
+    dependentChanged: function () {
+      var model = this.model;
+      var column = this.column;
+      editable = this.column.get("editable");
+
+      this.render();
+
+      is_editable = _.isFunction(editable) ? !!editable.apply(column, [model]) : !!editable;
+      if (is_editable){ this.$el.addClass("editable"); }
+      else { this.$el.removeClass("editable"); }
+
+      this.delegateEvents();
+      return this;
+    },
+    remove: Backgrid.Extension.DependentCell.prototype.remove
+  });
+
   return Backgrid;
 
 }));
