@@ -7,6 +7,6 @@ SELECT
     (SELECT
         s.args
      FROM pldbg_get_stack({{session_id}}::INTEGER) s
-     WHERE s.func = p.func AND s.pkg = p.pkg) AS args
+     WHERE s.func = p.func AND s.pkg = p.pkg ORDER BY s.level LIMIT 1) AS args
 FROM pldbg_select_frame({{session_id}}::INTEGER, {{frame_id}}::INTEGER) p
-{% endif %}
\ No newline at end of file
+{% endif %}
